# Explainable AI (XAI)

## Introduction

This repository contains explainable AI pipelines and functions that provide insightful plots.

## General Use Tools

The general use tools that are currently offered in the repository are listed in the table below.


| Tool |  Description | 
|-----------|-------------------|
| Model Details | Model Arfchitecture Visualisation combined with informations regarding total parameters and number of operations |
| Sample Details | Display input with the estimated output of the model |
| Convolution Layers Activation | Display the values of the convolutional layers stacked together | 
| Independent Components | Split the input into independent components to identify patterns |


## Algorithms

The XAI algorithms that are currently offered in the repository are listed in the table below.


| Algorithm |  Description | 
|-----------|-------------------|
| Vision SHAP | Display pixel values that have positive/negative impact on the output |
| Shap Overview | Showcase the behaviour of pixels with high standard deviation|
| Integrated Gradient |  | 
| DeepLift |  |



